@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto::API::ListImages;
-$XML::Grammar::Screenplay::FromProto::API::ListImages::VERSION = '0.22.7';
+$XML::Grammar::Screenplay::FromProto::API::ListImages::VERSION = '0.24.0';
 use strict;
 use warnings;
 
@@ -28,6 +28,22 @@ sub calc_doc__from_proto_text
     return $ret;
 }
 
+sub calc_doc__from_intermediate_xml
+{
+    my ( $self, $args ) = @_;
+
+    my $ret = XML::Grammar::Screenplay::API::ImageListDoc->new(
+        {
+            parser_class => 'XML::Grammar::Screenplay::FromProto::Parser::QnD',
+        }
+    );
+    my $xml_parser = XML::LibXML->new();
+    $xml_parser->validation(0);
+    $ret->_dom( $xml_parser->parse_file( $args->{filename} ) );
+
+    return $ret;
+}
+
 1;
 
 # __END__
@@ -42,7 +58,7 @@ __END__
 
 =head1 VERSION
 
-version 0.22.7
+version 0.24.0
 
 =head1 SYNOPSIS
 
@@ -52,6 +68,8 @@ version 0.22.7
 
 =head2 $self->calc_doc__from_proto_text({ %args })
 
+=head2 $self->calc_doc__from_intermediate_xml({ filename=>"path.screenplay-xml.xml", })
+
 TODO: document.
 
 =head2
